@@ -2,21 +2,24 @@
  * Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- *
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
- *
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * 
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
- *
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
+ * 
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -116,6 +119,15 @@ bool IOFireWireAVCUserClient::init( OSDictionary * dictionary )
     return res;
 }
 
+void IOFireWireAVCUserClient::stop( IOService * provider )
+{
+    //FireLog( "IOFireWireAVCUserClient::stop (0x%08X)\n",this);
+    
+    fStarted = false;
+    
+    IOService::stop(provider);
+}
+
 bool IOFireWireAVCUserClient::start( IOService * provider )
 {
     FWKLOG(( "IOFireWireAVCUserClient : starting\n" ));
@@ -316,6 +328,9 @@ IOReturn IOFireWireAVCUserClient::AVCCommand(UInt8 * cmd, UInt8 * response,
 {
     IOReturn res;
 
+	if(!fStarted )
+		return kIOReturnNoDevice;
+	
     res = fUnit->AVCCommand(cmd,len,response,size);
     IOSleep(8);	// Throttle iMovie
     return res;
@@ -329,6 +344,10 @@ IOReturn IOFireWireAVCUserClient::AVCCommandInGen(UInt8 * cmd, UInt8 * response,
     generation = *(UInt32 *)cmd;
     cmd += sizeof(UInt32);
     len -= sizeof(UInt32);
+	
+	if(!fStarted )
+		return kIOReturnNoDevice;
+	
     res = fUnit->AVCCommandInGeneration(generation,cmd,len,response,size);
     IOSleep(8);	// Throttle iMovie
     return res;
@@ -339,6 +358,9 @@ IOReturn IOFireWireAVCUserClient::updateAVCCommandTimeout
 {
     //IOLog("IOFireWireAVCUserClient : updateAVCCommandTimeout\n");
     
+	if(!fStarted )
+		return kIOReturnNoDevice;
+	
     fUnit->updateAVCCommandTimeout();
 
     return kIOReturnSuccess;
